## venra

[![Project Status: WIP](https://www.repostatus.org/badges/latest/wip.svg)](https://www.repostatus.org/#wip)
![Tests](https://github.com/codycollier/venra/workflows/Tests/badge.svg)
![Release](https://github.com/codycollier/venra/workflows/Upload%20Python%20Package/badge.svg)
[![PyPI version](https://badge.fury.io/py/venra.svg)](https://badge.fury.io/py/venra)


### Install

```bash
$ pip install venra
```

### Usage


```python

import venra

print(venra.stars)
```
